==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/user_ldap/l10n/eo.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to delete the server configuration" : "Malsukcesis forigo de la agordo de servilo",
    "Configuration incorrect" : "La agordaro malĝustas",
    "Configuration incomplete" : "La agordaro neplenas",
    "Configuration OK" : "La agordaro ĝustas",
    "Select groups" : "Elekti grupojn",
    "Select object classes" : "Elekti objektoklasojn",
    "{nthServer}. Server" : "{nthServer}. Servilo",
    "Confirm Deletion" : "Konfirmi forigon",
    "Select attributes" : "Elekti atribuojn",
    "_%s group found_::_%s groups found_" : ["%s grupo troviĝis","%s grupoj troviĝis"],
    "_%s user found_::_%s users found_" : ["%s uzanto troviĝis","%s uzanto troviĝis"],
    "Invalid Host" : "Nevalida gastigo",
    "Server" : "Servilo",
    "Users" : "Uzantoj",
    "Groups" : "Grupoj",
    "Test Configuration" : "Provi agordon",
    "Help" : "Helpo",
    "Other Attributes:" : "Aliaj atribuoj:",
    "1. Server" : "1. Servilo",
    "%s. Server:" : "%s. Servilo:",
    "Host" : "Gastigo",
    "You can omit the protocol, except you require SSL. Then start with ldaps://" : "Vi povas neglekti la protokolon, escepte se vi bezonas SSL-on. Tiuokaze, komencu per ldaps://",
    "Port" : "Pordo",
    "User DN" : "Uzanto-DN",
    "Password" : "Pasvorto",
    "For anonymous access, leave DN and Password empty." : "Por sennoman aliron, lasu DN-on kaj Pasvorton malplenaj.",
    "Back" : "Antaŭen",
    "Expert" : "Sperta",
    "Advanced" : "Progresinta",
    "Connection Settings" : "Agordo de konekto",
    "Disable Main Server" : "Malkapabligi la ĉefan servilon",
    "Turn off SSL certificate validation." : "Malkapabligi validkontrolon de SSL-atestiloj.",
    "Cache Time-To-Live" : "Vivotempo de la kaŝmemoro",
    "in seconds. A change empties the cache." : "sekunde. Ajna ŝanĝo malplenigas la kaŝmemoron.",
    "Directory Settings" : "Agordo de dosierujo",
    "User Display Name Field" : "Kampo de vidignomo de uzanto",
    "Base User Tree" : "Baza uzantarbo",
    "User Search Attributes" : "Atributoj de serĉo de uzanto",
    "Group Display Name Field" : "Kampo de vidignomo de grupo",
    "Base Group Tree" : "Baza gruparbo",
    "Group Search Attributes" : "Atribuoj de gruposerĉo",
    "Group-Member association" : "Asocio de grupo kaj membro",
    "Special Attributes" : "Specialaj atribuoj",
    "Quota Field" : "Kampo de kvoto",
    "in bytes" : "duumoke",
    "Email Field" : "Kampo de retpoŝto",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "Lasu malplena por uzantonomo (defaŭlto). Alie, specifu LDAP/AD-atributon.",
    "Internal Username" : "Ena uzantonomo",
    "Internal Username Attribute:" : "Atribuo de ena uzantonomo:",
    "UUID Attribute for Users:" : "UUID-atribuo por uzantoj:",
    "UUID Attribute for Groups:" : "UUID-atribuo por grupoj:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/user_ldap/l10n/eo.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to delete the server configuration" : "Malsukcesis forigo de la agordo de servilo",
    "Action does not exist" : "Ago ne ekzistas",
    "Configuration incorrect" : "La agordaro malĝustas",
    "Configuration incomplete" : "La agordaro neplenas",
    "Configuration OK" : "La agordaro ĝustas",
    "Select groups" : "Elekti grupojn",
    "Select object classes" : "Elekti objektoklasojn",
    "{nthServer}. Server" : "{nthServer}. Servilo",
    "Confirm Deletion" : "Konfirmi forigon",
    "Select attributes" : "Elekti atribuojn",
    "_%s group found_::_%s groups found_" : ["%s grupo troviĝis","%s grupoj troviĝis"],
    "_%s user found_::_%s users found_" : ["%s uzanto troviĝis","%s uzanto troviĝis"],
    "Invalid Host" : "Nevalida gastigo",
    "Server" : "Servilo",
    "Users" : "Uzantoj",
    "Groups" : "Grupoj",
    "Test Configuration" : "Provi agordon",
    "Help" : "Helpo",
    "Other Attributes:" : "Aliaj atribuoj:",
    "1. Server" : "1. Servilo",
    "%s. Server:" : "%s. Servilo:",
    "Host" : "Gastigo",
    "You can omit the protocol, except you require SSL. Then start with ldaps://" : "Vi povas neglekti la protokolon, escepte se vi bezonas SSL-on. Tiuokaze, komencu per ldaps://",
    "Port" : "Pordo",
    "User DN" : "Uzanto-DN",
    "Password" : "Pasvorto",
    "For anonymous access, leave DN and Password empty." : "Por sennoman aliron, lasu DN-on kaj Pasvorton malplenaj.",
    "Saving" : "Konservante",
    "Back" : "Antaŭen",
    "Continue" : "Daŭri",
    "LDAP" : "LDAP",
    "Expert" : "Sperta",
    "Advanced" : "Progresinta",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Averto</b>: la PHP-modulo LDAP ne instalatas; la motoro ne funkcios. Bonvolu peti vian sistemadministranton instali ĝin.",
    "Connection Settings" : "Agordo de konekto",
    "Disable Main Server" : "Malkapabligi la ĉefan servilon",
    "Turn off SSL certificate validation." : "Malkapabligi validkontrolon de SSL-atestiloj.",
    "Cache Time-To-Live" : "Vivotempo de la kaŝmemoro",
    "in seconds. A change empties the cache." : "sekunde. Ajna ŝanĝo malplenigas la kaŝmemoron.",
    "Directory Settings" : "Agordo de dosierujo",
    "User Display Name Field" : "Kampo de vidignomo de uzanto",
    "Base User Tree" : "Baza uzantarbo",
    "User Search Attributes" : "Atributoj de serĉo de uzanto",
    "Optional; one attribute per line" : "Malnepra; po unu atribuo por linio",
    "Group Display Name Field" : "Kampo de vidignomo de grupo",
    "Base Group Tree" : "Baza gruparbo",
    "Group Search Attributes" : "Atribuoj de gruposerĉo",
    "Group-Member association" : "Asocio de grupo kaj membro",
    "Nested Groups" : "Ingitaj grupoj",
    "Special Attributes" : "Specialaj atribuoj",
    "Quota Field" : "Kampo de kvoto",
    "in bytes" : "duumoke",
    "Email Field" : "Kampo de retpoŝto",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "Lasu malplena por uzantonomo (defaŭlto). Alie, specifu LDAP/AD-atributon.",
    "Internal Username" : "Ena uzantonomo",
    "Internal Username Attribute:" : "Atribuo de ena uzantonomo:",
    "UUID Attribute for Users:" : "UUID-atribuo por uzantoj:",
    "UUID Attribute for Groups:" : "UUID-atribuo por grupoj:",
    "{nthServer}. Server" : "{nthServer}. Servilo"
},
"nplurals=2; plural=(n != 1);");
